indicator

package
v0.0.0-...-86b7a09 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the indicator type in the database.
	Label = "indicator"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldIndicatorID holds the string denoting the indicator_id field in the database.
	FieldIndicatorID = "indicator_id"
	// FieldType holds the string denoting the type field in the database.
	FieldType = "type"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldScriptID holds the string denoting the script_id field in the database.
	FieldScriptID = "script_id"
	// FieldVersion holds the string denoting the version field in the database.
	FieldVersion = "version"
	// FieldParameters holds the string denoting the parameters field in the database.
	FieldParameters = "parameters"
	// FieldOutputs holds the string denoting the outputs field in the database.
	FieldOutputs = "outputs"
	// FieldEnabled holds the string denoting the enabled field in the database.
	FieldEnabled = "enabled"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldErrorMessage holds the string denoting the error_message field in the database.
	FieldErrorMessage = "error_message"
	// FieldLastCalculated holds the string denoting the last_calculated field in the database.
	FieldLastCalculated = "last_calculated"
	// FieldCalculationCount holds the string denoting the calculation_count field in the database.
	FieldCalculationCount = "calculation_count"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeStudySession holds the string denoting the study_session edge name in mutations.
	EdgeStudySession = "study_session"
	// EdgeData holds the string denoting the data edge name in mutations.
	EdgeData = "data"
	// Table holds the table name of the indicator in the database.
	Table = "indicators"
	// StudySessionTable is the table that holds the study_session relation/edge.
	StudySessionTable = "indicators"
	// StudySessionInverseTable is the table name for the StudySession entity.
	// It exists in this package in order to avoid circular dependency with the "studysession" package.
	StudySessionInverseTable = "study_sessions"
	// StudySessionColumn is the table column denoting the study_session relation/edge.
	StudySessionColumn = "study_session_indicators"
	// DataTable is the table that holds the data relation/edge.
	DataTable = "indicator_data"
	// DataInverseTable is the table name for the IndicatorData entity.
	// It exists in this package in order to avoid circular dependency with the "indicatordata" package.
	DataInverseTable = "indicator_data"
	// DataColumn is the table column denoting the data relation/edge.
	DataColumn = "indicator_data"
)
const DefaultStatus = StatusInitializing

StatusInitializing is the default value of the Status enum.

Variables

var (
	// DefaultVersion holds the default value on creation for the "version" field.
	DefaultVersion string
	// DefaultEnabled holds the default value on creation for the "enabled" field.
	DefaultEnabled bool
	// DefaultCalculationCount holds the default value on creation for the "calculation_count" field.
	DefaultCalculationCount int
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for indicator fields.

var ForeignKeys = []string{
	"study_session_indicators",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "indicators" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.Indicator) predicate.Indicator

And groups predicates with the AND operator between them.

func CalculationCount

func CalculationCount(v int) predicate.Indicator

CalculationCount applies equality check predicate on the "calculation_count" field. It's identical to CalculationCountEQ.

func CalculationCountEQ

func CalculationCountEQ(v int) predicate.Indicator

CalculationCountEQ applies the EQ predicate on the "calculation_count" field.

func CalculationCountGT

func CalculationCountGT(v int) predicate.Indicator

CalculationCountGT applies the GT predicate on the "calculation_count" field.

func CalculationCountGTE

func CalculationCountGTE(v int) predicate.Indicator

CalculationCountGTE applies the GTE predicate on the "calculation_count" field.

func CalculationCountIn

func CalculationCountIn(vs ...int) predicate.Indicator

CalculationCountIn applies the In predicate on the "calculation_count" field.

func CalculationCountLT

func CalculationCountLT(v int) predicate.Indicator

CalculationCountLT applies the LT predicate on the "calculation_count" field.

func CalculationCountLTE

func CalculationCountLTE(v int) predicate.Indicator

CalculationCountLTE applies the LTE predicate on the "calculation_count" field.

func CalculationCountNEQ

func CalculationCountNEQ(v int) predicate.Indicator

CalculationCountNEQ applies the NEQ predicate on the "calculation_count" field.

func CalculationCountNotIn

func CalculationCountNotIn(vs ...int) predicate.Indicator

CalculationCountNotIn applies the NotIn predicate on the "calculation_count" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Indicator

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Indicator

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Indicator

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Indicator

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Indicator

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Indicator

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Indicator

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Indicator

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Indicator

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Enabled

func Enabled(v bool) predicate.Indicator

Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.

func EnabledEQ

func EnabledEQ(v bool) predicate.Indicator

EnabledEQ applies the EQ predicate on the "enabled" field.

func EnabledNEQ

func EnabledNEQ(v bool) predicate.Indicator

EnabledNEQ applies the NEQ predicate on the "enabled" field.

func ErrorMessage

func ErrorMessage(v string) predicate.Indicator

ErrorMessage applies equality check predicate on the "error_message" field. It's identical to ErrorMessageEQ.

func ErrorMessageContains

func ErrorMessageContains(v string) predicate.Indicator

ErrorMessageContains applies the Contains predicate on the "error_message" field.

func ErrorMessageContainsFold

func ErrorMessageContainsFold(v string) predicate.Indicator

ErrorMessageContainsFold applies the ContainsFold predicate on the "error_message" field.

func ErrorMessageEQ

func ErrorMessageEQ(v string) predicate.Indicator

ErrorMessageEQ applies the EQ predicate on the "error_message" field.

func ErrorMessageEqualFold

func ErrorMessageEqualFold(v string) predicate.Indicator

ErrorMessageEqualFold applies the EqualFold predicate on the "error_message" field.

func ErrorMessageGT

func ErrorMessageGT(v string) predicate.Indicator

ErrorMessageGT applies the GT predicate on the "error_message" field.

func ErrorMessageGTE

func ErrorMessageGTE(v string) predicate.Indicator

ErrorMessageGTE applies the GTE predicate on the "error_message" field.

func ErrorMessageHasPrefix

func ErrorMessageHasPrefix(v string) predicate.Indicator

ErrorMessageHasPrefix applies the HasPrefix predicate on the "error_message" field.

func ErrorMessageHasSuffix

func ErrorMessageHasSuffix(v string) predicate.Indicator

ErrorMessageHasSuffix applies the HasSuffix predicate on the "error_message" field.

func ErrorMessageIn

func ErrorMessageIn(vs ...string) predicate.Indicator

ErrorMessageIn applies the In predicate on the "error_message" field.

func ErrorMessageIsNil

func ErrorMessageIsNil() predicate.Indicator

ErrorMessageIsNil applies the IsNil predicate on the "error_message" field.

func ErrorMessageLT

func ErrorMessageLT(v string) predicate.Indicator

ErrorMessageLT applies the LT predicate on the "error_message" field.

func ErrorMessageLTE

func ErrorMessageLTE(v string) predicate.Indicator

ErrorMessageLTE applies the LTE predicate on the "error_message" field.

func ErrorMessageNEQ

func ErrorMessageNEQ(v string) predicate.Indicator

ErrorMessageNEQ applies the NEQ predicate on the "error_message" field.

func ErrorMessageNotIn

func ErrorMessageNotIn(vs ...string) predicate.Indicator

ErrorMessageNotIn applies the NotIn predicate on the "error_message" field.

func ErrorMessageNotNil

func ErrorMessageNotNil() predicate.Indicator

ErrorMessageNotNil applies the NotNil predicate on the "error_message" field.

func HasData

func HasData() predicate.Indicator

HasData applies the HasEdge predicate on the "data" edge.

func HasDataWith

func HasDataWith(preds ...predicate.IndicatorData) predicate.Indicator

HasDataWith applies the HasEdge predicate on the "data" edge with a given conditions (other predicates).

func HasStudySession

func HasStudySession() predicate.Indicator

HasStudySession applies the HasEdge predicate on the "study_session" edge.

func HasStudySessionWith

func HasStudySessionWith(preds ...predicate.StudySession) predicate.Indicator

HasStudySessionWith applies the HasEdge predicate on the "study_session" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Indicator

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Indicator

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Indicator

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Indicator

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Indicator

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Indicator

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Indicator

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Indicator

IDNotIn applies the NotIn predicate on the ID field.

func IndicatorID

func IndicatorID(v string) predicate.Indicator

IndicatorID applies equality check predicate on the "indicator_id" field. It's identical to IndicatorIDEQ.

func IndicatorIDContains

func IndicatorIDContains(v string) predicate.Indicator

IndicatorIDContains applies the Contains predicate on the "indicator_id" field.

func IndicatorIDContainsFold

func IndicatorIDContainsFold(v string) predicate.Indicator

IndicatorIDContainsFold applies the ContainsFold predicate on the "indicator_id" field.

func IndicatorIDEQ

func IndicatorIDEQ(v string) predicate.Indicator

IndicatorIDEQ applies the EQ predicate on the "indicator_id" field.

func IndicatorIDEqualFold

func IndicatorIDEqualFold(v string) predicate.Indicator

IndicatorIDEqualFold applies the EqualFold predicate on the "indicator_id" field.

func IndicatorIDGT

func IndicatorIDGT(v string) predicate.Indicator

IndicatorIDGT applies the GT predicate on the "indicator_id" field.

func IndicatorIDGTE

func IndicatorIDGTE(v string) predicate.Indicator

IndicatorIDGTE applies the GTE predicate on the "indicator_id" field.

func IndicatorIDHasPrefix

func IndicatorIDHasPrefix(v string) predicate.Indicator

IndicatorIDHasPrefix applies the HasPrefix predicate on the "indicator_id" field.

func IndicatorIDHasSuffix

func IndicatorIDHasSuffix(v string) predicate.Indicator

IndicatorIDHasSuffix applies the HasSuffix predicate on the "indicator_id" field.

func IndicatorIDIn

func IndicatorIDIn(vs ...string) predicate.Indicator

IndicatorIDIn applies the In predicate on the "indicator_id" field.

func IndicatorIDLT

func IndicatorIDLT(v string) predicate.Indicator

IndicatorIDLT applies the LT predicate on the "indicator_id" field.

func IndicatorIDLTE

func IndicatorIDLTE(v string) predicate.Indicator

IndicatorIDLTE applies the LTE predicate on the "indicator_id" field.

func IndicatorIDNEQ

func IndicatorIDNEQ(v string) predicate.Indicator

IndicatorIDNEQ applies the NEQ predicate on the "indicator_id" field.

func IndicatorIDNotIn

func IndicatorIDNotIn(vs ...string) predicate.Indicator

IndicatorIDNotIn applies the NotIn predicate on the "indicator_id" field.

func LastCalculated

func LastCalculated(v time.Time) predicate.Indicator

LastCalculated applies equality check predicate on the "last_calculated" field. It's identical to LastCalculatedEQ.

func LastCalculatedEQ

func LastCalculatedEQ(v time.Time) predicate.Indicator

LastCalculatedEQ applies the EQ predicate on the "last_calculated" field.

func LastCalculatedGT

func LastCalculatedGT(v time.Time) predicate.Indicator

LastCalculatedGT applies the GT predicate on the "last_calculated" field.

func LastCalculatedGTE

func LastCalculatedGTE(v time.Time) predicate.Indicator

LastCalculatedGTE applies the GTE predicate on the "last_calculated" field.

func LastCalculatedIn

func LastCalculatedIn(vs ...time.Time) predicate.Indicator

LastCalculatedIn applies the In predicate on the "last_calculated" field.

func LastCalculatedIsNil

func LastCalculatedIsNil() predicate.Indicator

LastCalculatedIsNil applies the IsNil predicate on the "last_calculated" field.

func LastCalculatedLT

func LastCalculatedLT(v time.Time) predicate.Indicator

LastCalculatedLT applies the LT predicate on the "last_calculated" field.

func LastCalculatedLTE

func LastCalculatedLTE(v time.Time) predicate.Indicator

LastCalculatedLTE applies the LTE predicate on the "last_calculated" field.

func LastCalculatedNEQ

func LastCalculatedNEQ(v time.Time) predicate.Indicator

LastCalculatedNEQ applies the NEQ predicate on the "last_calculated" field.

func LastCalculatedNotIn

func LastCalculatedNotIn(vs ...time.Time) predicate.Indicator

LastCalculatedNotIn applies the NotIn predicate on the "last_calculated" field.

func LastCalculatedNotNil

func LastCalculatedNotNil() predicate.Indicator

LastCalculatedNotNil applies the NotNil predicate on the "last_calculated" field.

func Name

func Name(v string) predicate.Indicator

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Indicator

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Indicator

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Indicator

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Indicator

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Indicator

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Indicator

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Indicator

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Indicator

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Indicator

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Indicator

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Indicator

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Indicator

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Indicator

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Indicator) predicate.Indicator

Or groups predicates with the OR operator between them.

func ScriptID

func ScriptID(v string) predicate.Indicator

ScriptID applies equality check predicate on the "script_id" field. It's identical to ScriptIDEQ.

func ScriptIDContains

func ScriptIDContains(v string) predicate.Indicator

ScriptIDContains applies the Contains predicate on the "script_id" field.

func ScriptIDContainsFold

func ScriptIDContainsFold(v string) predicate.Indicator

ScriptIDContainsFold applies the ContainsFold predicate on the "script_id" field.

func ScriptIDEQ

func ScriptIDEQ(v string) predicate.Indicator

ScriptIDEQ applies the EQ predicate on the "script_id" field.

func ScriptIDEqualFold

func ScriptIDEqualFold(v string) predicate.Indicator

ScriptIDEqualFold applies the EqualFold predicate on the "script_id" field.

func ScriptIDGT

func ScriptIDGT(v string) predicate.Indicator

ScriptIDGT applies the GT predicate on the "script_id" field.

func ScriptIDGTE

func ScriptIDGTE(v string) predicate.Indicator

ScriptIDGTE applies the GTE predicate on the "script_id" field.

func ScriptIDHasPrefix

func ScriptIDHasPrefix(v string) predicate.Indicator

ScriptIDHasPrefix applies the HasPrefix predicate on the "script_id" field.

func ScriptIDHasSuffix

func ScriptIDHasSuffix(v string) predicate.Indicator

ScriptIDHasSuffix applies the HasSuffix predicate on the "script_id" field.

func ScriptIDIn

func ScriptIDIn(vs ...string) predicate.Indicator

ScriptIDIn applies the In predicate on the "script_id" field.

func ScriptIDIsNil

func ScriptIDIsNil() predicate.Indicator

ScriptIDIsNil applies the IsNil predicate on the "script_id" field.

func ScriptIDLT

func ScriptIDLT(v string) predicate.Indicator

ScriptIDLT applies the LT predicate on the "script_id" field.

func ScriptIDLTE

func ScriptIDLTE(v string) predicate.Indicator

ScriptIDLTE applies the LTE predicate on the "script_id" field.

func ScriptIDNEQ

func ScriptIDNEQ(v string) predicate.Indicator

ScriptIDNEQ applies the NEQ predicate on the "script_id" field.

func ScriptIDNotIn

func ScriptIDNotIn(vs ...string) predicate.Indicator

ScriptIDNotIn applies the NotIn predicate on the "script_id" field.

func ScriptIDNotNil

func ScriptIDNotNil() predicate.Indicator

ScriptIDNotNil applies the NotNil predicate on the "script_id" field.

func StatusEQ

func StatusEQ(v Status) predicate.Indicator

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.Indicator

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v Status) predicate.Indicator

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.Indicator

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func TypeEQ

func TypeEQ(v Type) predicate.Indicator

TypeEQ applies the EQ predicate on the "type" field.

func TypeIn

func TypeIn(vs ...Type) predicate.Indicator

TypeIn applies the In predicate on the "type" field.

func TypeNEQ

func TypeNEQ(v Type) predicate.Indicator

TypeNEQ applies the NEQ predicate on the "type" field.

func TypeNotIn

func TypeNotIn(vs ...Type) predicate.Indicator

TypeNotIn applies the NotIn predicate on the "type" field.

func TypeValidator

func TypeValidator(_type Type) error

TypeValidator is a validator for the "type" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Indicator

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Indicator

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Indicator

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Indicator

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Indicator

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Indicator

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Indicator

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Indicator

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Indicator

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Version

func Version(v string) predicate.Indicator

Version applies equality check predicate on the "version" field. It's identical to VersionEQ.

func VersionContains

func VersionContains(v string) predicate.Indicator

VersionContains applies the Contains predicate on the "version" field.

func VersionContainsFold

func VersionContainsFold(v string) predicate.Indicator

VersionContainsFold applies the ContainsFold predicate on the "version" field.

func VersionEQ

func VersionEQ(v string) predicate.Indicator

VersionEQ applies the EQ predicate on the "version" field.

func VersionEqualFold

func VersionEqualFold(v string) predicate.Indicator

VersionEqualFold applies the EqualFold predicate on the "version" field.

func VersionGT

func VersionGT(v string) predicate.Indicator

VersionGT applies the GT predicate on the "version" field.

func VersionGTE

func VersionGTE(v string) predicate.Indicator

VersionGTE applies the GTE predicate on the "version" field.

func VersionHasPrefix

func VersionHasPrefix(v string) predicate.Indicator

VersionHasPrefix applies the HasPrefix predicate on the "version" field.

func VersionHasSuffix

func VersionHasSuffix(v string) predicate.Indicator

VersionHasSuffix applies the HasSuffix predicate on the "version" field.

func VersionIn

func VersionIn(vs ...string) predicate.Indicator

VersionIn applies the In predicate on the "version" field.

func VersionLT

func VersionLT(v string) predicate.Indicator

VersionLT applies the LT predicate on the "version" field.

func VersionLTE

func VersionLTE(v string) predicate.Indicator

VersionLTE applies the LTE predicate on the "version" field.

func VersionNEQ

func VersionNEQ(v string) predicate.Indicator

VersionNEQ applies the NEQ predicate on the "version" field.

func VersionNotIn

func VersionNotIn(vs ...string) predicate.Indicator

VersionNotIn applies the NotIn predicate on the "version" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Indicator queries.

func ByCalculationCount

func ByCalculationCount(opts ...sql.OrderTermOption) OrderOption

ByCalculationCount orders the results by the calculation_count field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByData

func ByData(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByData orders the results by data terms.

func ByDataCount

func ByDataCount(opts ...sql.OrderTermOption) OrderOption

ByDataCount orders the results by data count.

func ByEnabled

func ByEnabled(opts ...sql.OrderTermOption) OrderOption

ByEnabled orders the results by the enabled field.

func ByErrorMessage

func ByErrorMessage(opts ...sql.OrderTermOption) OrderOption

ByErrorMessage orders the results by the error_message field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIndicatorID

func ByIndicatorID(opts ...sql.OrderTermOption) OrderOption

ByIndicatorID orders the results by the indicator_id field.

func ByLastCalculated

func ByLastCalculated(opts ...sql.OrderTermOption) OrderOption

ByLastCalculated orders the results by the last_calculated field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByScriptID

func ByScriptID(opts ...sql.OrderTermOption) OrderOption

ByScriptID orders the results by the script_id field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByStudySessionField

func ByStudySessionField(field string, opts ...sql.OrderTermOption) OrderOption

ByStudySessionField orders the results by study_session field.

func ByType

func ByType(opts ...sql.OrderTermOption) OrderOption

ByType orders the results by the type field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByVersion

func ByVersion(opts ...sql.OrderTermOption) OrderOption

ByVersion orders the results by the version field.

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusInitializing Status = "initializing"
	StatusRunning      Status = "running"
	StatusPaused       Status = "paused"
	StatusError        Status = "error"
	StatusCompleted    Status = "completed"
)

Status values.

func (Status) String

func (s Status) String() string

type Type

type Type string

Type defines the type for the "type" enum field.

const (
	TypeRSI        Type = "RSI"
	TypeMACD       Type = "MACD"
	TypeBB         Type = "BB"
	TypeMA         Type = "MA"
	TypeEMA        Type = "EMA"
	TypeSMA        Type = "SMA"
	TypeWMA        Type = "WMA"
	TypeSTOCH      Type = "STOCH"
	TypeWILLIAMS_R Type = "WILLIAMS_R"
	TypeCCI        Type = "CCI"
	TypeMOM        Type = "MOM"
	TypeROC        Type = "ROC"
	TypeADX        Type = "ADX"
	TypeATR        Type = "ATR"
	TypeVOLUME     Type = "VOLUME"
	TypeOBV        Type = "OBV"
	TypeVWAP       Type = "VWAP"
	TypeICHIMOKU   Type = "ICHIMOKU"
	TypeFIBONACCI  Type = "FIBONACCI"
	TypePIVOT      Type = "PIVOT"
	TypeCUSTOM     Type = "CUSTOM"
)

Type values.

func (Type) String

func (_type Type) String() string

Jump to