Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Indicator) predicate.Indicator
- func CalculationCount(v int) predicate.Indicator
- func CalculationCountEQ(v int) predicate.Indicator
- func CalculationCountGT(v int) predicate.Indicator
- func CalculationCountGTE(v int) predicate.Indicator
- func CalculationCountIn(vs ...int) predicate.Indicator
- func CalculationCountLT(v int) predicate.Indicator
- func CalculationCountLTE(v int) predicate.Indicator
- func CalculationCountNEQ(v int) predicate.Indicator
- func CalculationCountNotIn(vs ...int) predicate.Indicator
- func CreatedAt(v time.Time) predicate.Indicator
- func CreatedAtEQ(v time.Time) predicate.Indicator
- func CreatedAtGT(v time.Time) predicate.Indicator
- func CreatedAtGTE(v time.Time) predicate.Indicator
- func CreatedAtIn(vs ...time.Time) predicate.Indicator
- func CreatedAtLT(v time.Time) predicate.Indicator
- func CreatedAtLTE(v time.Time) predicate.Indicator
- func CreatedAtNEQ(v time.Time) predicate.Indicator
- func CreatedAtNotIn(vs ...time.Time) predicate.Indicator
- func Enabled(v bool) predicate.Indicator
- func EnabledEQ(v bool) predicate.Indicator
- func EnabledNEQ(v bool) predicate.Indicator
- func ErrorMessage(v string) predicate.Indicator
- func ErrorMessageContains(v string) predicate.Indicator
- func ErrorMessageContainsFold(v string) predicate.Indicator
- func ErrorMessageEQ(v string) predicate.Indicator
- func ErrorMessageEqualFold(v string) predicate.Indicator
- func ErrorMessageGT(v string) predicate.Indicator
- func ErrorMessageGTE(v string) predicate.Indicator
- func ErrorMessageHasPrefix(v string) predicate.Indicator
- func ErrorMessageHasSuffix(v string) predicate.Indicator
- func ErrorMessageIn(vs ...string) predicate.Indicator
- func ErrorMessageIsNil() predicate.Indicator
- func ErrorMessageLT(v string) predicate.Indicator
- func ErrorMessageLTE(v string) predicate.Indicator
- func ErrorMessageNEQ(v string) predicate.Indicator
- func ErrorMessageNotIn(vs ...string) predicate.Indicator
- func ErrorMessageNotNil() predicate.Indicator
- func HasData() predicate.Indicator
- func HasDataWith(preds ...predicate.IndicatorData) predicate.Indicator
- func HasStudySession() predicate.Indicator
- func HasStudySessionWith(preds ...predicate.StudySession) predicate.Indicator
- func ID(id uuid.UUID) predicate.Indicator
- func IDEQ(id uuid.UUID) predicate.Indicator
- func IDGT(id uuid.UUID) predicate.Indicator
- func IDGTE(id uuid.UUID) predicate.Indicator
- func IDIn(ids ...uuid.UUID) predicate.Indicator
- func IDLT(id uuid.UUID) predicate.Indicator
- func IDLTE(id uuid.UUID) predicate.Indicator
- func IDNEQ(id uuid.UUID) predicate.Indicator
- func IDNotIn(ids ...uuid.UUID) predicate.Indicator
- func IndicatorID(v string) predicate.Indicator
- func IndicatorIDContains(v string) predicate.Indicator
- func IndicatorIDContainsFold(v string) predicate.Indicator
- func IndicatorIDEQ(v string) predicate.Indicator
- func IndicatorIDEqualFold(v string) predicate.Indicator
- func IndicatorIDGT(v string) predicate.Indicator
- func IndicatorIDGTE(v string) predicate.Indicator
- func IndicatorIDHasPrefix(v string) predicate.Indicator
- func IndicatorIDHasSuffix(v string) predicate.Indicator
- func IndicatorIDIn(vs ...string) predicate.Indicator
- func IndicatorIDLT(v string) predicate.Indicator
- func IndicatorIDLTE(v string) predicate.Indicator
- func IndicatorIDNEQ(v string) predicate.Indicator
- func IndicatorIDNotIn(vs ...string) predicate.Indicator
- func LastCalculated(v time.Time) predicate.Indicator
- func LastCalculatedEQ(v time.Time) predicate.Indicator
- func LastCalculatedGT(v time.Time) predicate.Indicator
- func LastCalculatedGTE(v time.Time) predicate.Indicator
- func LastCalculatedIn(vs ...time.Time) predicate.Indicator
- func LastCalculatedIsNil() predicate.Indicator
- func LastCalculatedLT(v time.Time) predicate.Indicator
- func LastCalculatedLTE(v time.Time) predicate.Indicator
- func LastCalculatedNEQ(v time.Time) predicate.Indicator
- func LastCalculatedNotIn(vs ...time.Time) predicate.Indicator
- func LastCalculatedNotNil() predicate.Indicator
- func Name(v string) predicate.Indicator
- func NameContains(v string) predicate.Indicator
- func NameContainsFold(v string) predicate.Indicator
- func NameEQ(v string) predicate.Indicator
- func NameEqualFold(v string) predicate.Indicator
- func NameGT(v string) predicate.Indicator
- func NameGTE(v string) predicate.Indicator
- func NameHasPrefix(v string) predicate.Indicator
- func NameHasSuffix(v string) predicate.Indicator
- func NameIn(vs ...string) predicate.Indicator
- func NameLT(v string) predicate.Indicator
- func NameLTE(v string) predicate.Indicator
- func NameNEQ(v string) predicate.Indicator
- func NameNotIn(vs ...string) predicate.Indicator
- func Not(p predicate.Indicator) predicate.Indicator
- func Or(predicates ...predicate.Indicator) predicate.Indicator
- func ScriptID(v string) predicate.Indicator
- func ScriptIDContains(v string) predicate.Indicator
- func ScriptIDContainsFold(v string) predicate.Indicator
- func ScriptIDEQ(v string) predicate.Indicator
- func ScriptIDEqualFold(v string) predicate.Indicator
- func ScriptIDGT(v string) predicate.Indicator
- func ScriptIDGTE(v string) predicate.Indicator
- func ScriptIDHasPrefix(v string) predicate.Indicator
- func ScriptIDHasSuffix(v string) predicate.Indicator
- func ScriptIDIn(vs ...string) predicate.Indicator
- func ScriptIDIsNil() predicate.Indicator
- func ScriptIDLT(v string) predicate.Indicator
- func ScriptIDLTE(v string) predicate.Indicator
- func ScriptIDNEQ(v string) predicate.Indicator
- func ScriptIDNotIn(vs ...string) predicate.Indicator
- func ScriptIDNotNil() predicate.Indicator
- func StatusEQ(v Status) predicate.Indicator
- func StatusIn(vs ...Status) predicate.Indicator
- func StatusNEQ(v Status) predicate.Indicator
- func StatusNotIn(vs ...Status) predicate.Indicator
- func StatusValidator(s Status) error
- func TypeEQ(v Type) predicate.Indicator
- func TypeIn(vs ...Type) predicate.Indicator
- func TypeNEQ(v Type) predicate.Indicator
- func TypeNotIn(vs ...Type) predicate.Indicator
- func TypeValidator(_type Type) error
- func UpdatedAt(v time.Time) predicate.Indicator
- func UpdatedAtEQ(v time.Time) predicate.Indicator
- func UpdatedAtGT(v time.Time) predicate.Indicator
- func UpdatedAtGTE(v time.Time) predicate.Indicator
- func UpdatedAtIn(vs ...time.Time) predicate.Indicator
- func UpdatedAtLT(v time.Time) predicate.Indicator
- func UpdatedAtLTE(v time.Time) predicate.Indicator
- func UpdatedAtNEQ(v time.Time) predicate.Indicator
- func UpdatedAtNotIn(vs ...time.Time) predicate.Indicator
- func ValidColumn(column string) bool
- func Version(v string) predicate.Indicator
- func VersionContains(v string) predicate.Indicator
- func VersionContainsFold(v string) predicate.Indicator
- func VersionEQ(v string) predicate.Indicator
- func VersionEqualFold(v string) predicate.Indicator
- func VersionGT(v string) predicate.Indicator
- func VersionGTE(v string) predicate.Indicator
- func VersionHasPrefix(v string) predicate.Indicator
- func VersionHasSuffix(v string) predicate.Indicator
- func VersionIn(vs ...string) predicate.Indicator
- func VersionLT(v string) predicate.Indicator
- func VersionLTE(v string) predicate.Indicator
- func VersionNEQ(v string) predicate.Indicator
- func VersionNotIn(vs ...string) predicate.Indicator
- type OrderOption
- func ByCalculationCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByData(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByDataCount(opts ...sql.OrderTermOption) OrderOption
- func ByEnabled(opts ...sql.OrderTermOption) OrderOption
- func ByErrorMessage(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIndicatorID(opts ...sql.OrderTermOption) OrderOption
- func ByLastCalculated(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByScriptID(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByStudySessionField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByType(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByVersion(opts ...sql.OrderTermOption) OrderOption
- type Status
- type Type
Constants ¶
const ( // Label holds the string label denoting the indicator type in the database. Label = "indicator" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldIndicatorID holds the string denoting the indicator_id field in the database. FieldIndicatorID = "indicator_id" // FieldType holds the string denoting the type field in the database. FieldType = "type" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldScriptID holds the string denoting the script_id field in the database. FieldScriptID = "script_id" // FieldVersion holds the string denoting the version field in the database. FieldVersion = "version" // FieldParameters holds the string denoting the parameters field in the database. FieldParameters = "parameters" // FieldOutputs holds the string denoting the outputs field in the database. FieldOutputs = "outputs" // FieldEnabled holds the string denoting the enabled field in the database. FieldEnabled = "enabled" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldErrorMessage holds the string denoting the error_message field in the database. FieldErrorMessage = "error_message" // FieldLastCalculated holds the string denoting the last_calculated field in the database. FieldLastCalculated = "last_calculated" // FieldCalculationCount holds the string denoting the calculation_count field in the database. FieldCalculationCount = "calculation_count" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeStudySession holds the string denoting the study_session edge name in mutations. EdgeStudySession = "study_session" // EdgeData holds the string denoting the data edge name in mutations. EdgeData = "data" // Table holds the table name of the indicator in the database. Table = "indicators" // StudySessionTable is the table that holds the study_session relation/edge. StudySessionTable = "indicators" // StudySessionInverseTable is the table name for the StudySession entity. // It exists in this package in order to avoid circular dependency with the "studysession" package. StudySessionInverseTable = "study_sessions" // StudySessionColumn is the table column denoting the study_session relation/edge. StudySessionColumn = "study_session_indicators" // DataTable is the table that holds the data relation/edge. DataTable = "indicator_data" // DataInverseTable is the table name for the IndicatorData entity. // It exists in this package in order to avoid circular dependency with the "indicatordata" package. DataInverseTable = "indicator_data" // DataColumn is the table column denoting the data relation/edge. DataColumn = "indicator_data" )
const DefaultStatus = StatusInitializing
StatusInitializing is the default value of the Status enum.
Variables ¶
var ( // DefaultVersion holds the default value on creation for the "version" field. DefaultVersion string // DefaultEnabled holds the default value on creation for the "enabled" field. DefaultEnabled bool // DefaultCalculationCount holds the default value on creation for the "calculation_count" field. DefaultCalculationCount int // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldIndicatorID, FieldType, FieldName, FieldScriptID, FieldVersion, FieldParameters, FieldOutputs, FieldEnabled, FieldStatus, FieldErrorMessage, FieldLastCalculated, FieldCalculationCount, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for indicator fields.
var ForeignKeys = []string{
"study_session_indicators",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "indicators" table and are not defined as standalone fields in the schema.
Functions ¶
func CalculationCount ¶
CalculationCount applies equality check predicate on the "calculation_count" field. It's identical to CalculationCountEQ.
func CalculationCountEQ ¶
CalculationCountEQ applies the EQ predicate on the "calculation_count" field.
func CalculationCountGT ¶
CalculationCountGT applies the GT predicate on the "calculation_count" field.
func CalculationCountGTE ¶
CalculationCountGTE applies the GTE predicate on the "calculation_count" field.
func CalculationCountIn ¶
CalculationCountIn applies the In predicate on the "calculation_count" field.
func CalculationCountLT ¶
CalculationCountLT applies the LT predicate on the "calculation_count" field.
func CalculationCountLTE ¶
CalculationCountLTE applies the LTE predicate on the "calculation_count" field.
func CalculationCountNEQ ¶
CalculationCountNEQ applies the NEQ predicate on the "calculation_count" field.
func CalculationCountNotIn ¶
CalculationCountNotIn applies the NotIn predicate on the "calculation_count" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Enabled ¶
Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.
func EnabledNEQ ¶
EnabledNEQ applies the NEQ predicate on the "enabled" field.
func ErrorMessage ¶
ErrorMessage applies equality check predicate on the "error_message" field. It's identical to ErrorMessageEQ.
func ErrorMessageContains ¶
ErrorMessageContains applies the Contains predicate on the "error_message" field.
func ErrorMessageContainsFold ¶
ErrorMessageContainsFold applies the ContainsFold predicate on the "error_message" field.
func ErrorMessageEQ ¶
ErrorMessageEQ applies the EQ predicate on the "error_message" field.
func ErrorMessageEqualFold ¶
ErrorMessageEqualFold applies the EqualFold predicate on the "error_message" field.
func ErrorMessageGT ¶
ErrorMessageGT applies the GT predicate on the "error_message" field.
func ErrorMessageGTE ¶
ErrorMessageGTE applies the GTE predicate on the "error_message" field.
func ErrorMessageHasPrefix ¶
ErrorMessageHasPrefix applies the HasPrefix predicate on the "error_message" field.
func ErrorMessageHasSuffix ¶
ErrorMessageHasSuffix applies the HasSuffix predicate on the "error_message" field.
func ErrorMessageIn ¶
ErrorMessageIn applies the In predicate on the "error_message" field.
func ErrorMessageIsNil ¶
ErrorMessageIsNil applies the IsNil predicate on the "error_message" field.
func ErrorMessageLT ¶
ErrorMessageLT applies the LT predicate on the "error_message" field.
func ErrorMessageLTE ¶
ErrorMessageLTE applies the LTE predicate on the "error_message" field.
func ErrorMessageNEQ ¶
ErrorMessageNEQ applies the NEQ predicate on the "error_message" field.
func ErrorMessageNotIn ¶
ErrorMessageNotIn applies the NotIn predicate on the "error_message" field.
func ErrorMessageNotNil ¶
ErrorMessageNotNil applies the NotNil predicate on the "error_message" field.
func HasDataWith ¶
func HasDataWith(preds ...predicate.IndicatorData) predicate.Indicator
HasDataWith applies the HasEdge predicate on the "data" edge with a given conditions (other predicates).
func HasStudySession ¶
HasStudySession applies the HasEdge predicate on the "study_session" edge.
func HasStudySessionWith ¶
func HasStudySessionWith(preds ...predicate.StudySession) predicate.Indicator
HasStudySessionWith applies the HasEdge predicate on the "study_session" edge with a given conditions (other predicates).
func IndicatorID ¶
IndicatorID applies equality check predicate on the "indicator_id" field. It's identical to IndicatorIDEQ.
func IndicatorIDContains ¶
IndicatorIDContains applies the Contains predicate on the "indicator_id" field.
func IndicatorIDContainsFold ¶
IndicatorIDContainsFold applies the ContainsFold predicate on the "indicator_id" field.
func IndicatorIDEQ ¶
IndicatorIDEQ applies the EQ predicate on the "indicator_id" field.
func IndicatorIDEqualFold ¶
IndicatorIDEqualFold applies the EqualFold predicate on the "indicator_id" field.
func IndicatorIDGT ¶
IndicatorIDGT applies the GT predicate on the "indicator_id" field.
func IndicatorIDGTE ¶
IndicatorIDGTE applies the GTE predicate on the "indicator_id" field.
func IndicatorIDHasPrefix ¶
IndicatorIDHasPrefix applies the HasPrefix predicate on the "indicator_id" field.
func IndicatorIDHasSuffix ¶
IndicatorIDHasSuffix applies the HasSuffix predicate on the "indicator_id" field.
func IndicatorIDIn ¶
IndicatorIDIn applies the In predicate on the "indicator_id" field.
func IndicatorIDLT ¶
IndicatorIDLT applies the LT predicate on the "indicator_id" field.
func IndicatorIDLTE ¶
IndicatorIDLTE applies the LTE predicate on the "indicator_id" field.
func IndicatorIDNEQ ¶
IndicatorIDNEQ applies the NEQ predicate on the "indicator_id" field.
func IndicatorIDNotIn ¶
IndicatorIDNotIn applies the NotIn predicate on the "indicator_id" field.
func LastCalculated ¶
LastCalculated applies equality check predicate on the "last_calculated" field. It's identical to LastCalculatedEQ.
func LastCalculatedEQ ¶
LastCalculatedEQ applies the EQ predicate on the "last_calculated" field.
func LastCalculatedGT ¶
LastCalculatedGT applies the GT predicate on the "last_calculated" field.
func LastCalculatedGTE ¶
LastCalculatedGTE applies the GTE predicate on the "last_calculated" field.
func LastCalculatedIn ¶
LastCalculatedIn applies the In predicate on the "last_calculated" field.
func LastCalculatedIsNil ¶
LastCalculatedIsNil applies the IsNil predicate on the "last_calculated" field.
func LastCalculatedLT ¶
LastCalculatedLT applies the LT predicate on the "last_calculated" field.
func LastCalculatedLTE ¶
LastCalculatedLTE applies the LTE predicate on the "last_calculated" field.
func LastCalculatedNEQ ¶
LastCalculatedNEQ applies the NEQ predicate on the "last_calculated" field.
func LastCalculatedNotIn ¶
LastCalculatedNotIn applies the NotIn predicate on the "last_calculated" field.
func LastCalculatedNotNil ¶
LastCalculatedNotNil applies the NotNil predicate on the "last_calculated" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func ScriptID ¶
ScriptID applies equality check predicate on the "script_id" field. It's identical to ScriptIDEQ.
func ScriptIDContains ¶
ScriptIDContains applies the Contains predicate on the "script_id" field.
func ScriptIDContainsFold ¶
ScriptIDContainsFold applies the ContainsFold predicate on the "script_id" field.
func ScriptIDEQ ¶
ScriptIDEQ applies the EQ predicate on the "script_id" field.
func ScriptIDEqualFold ¶
ScriptIDEqualFold applies the EqualFold predicate on the "script_id" field.
func ScriptIDGT ¶
ScriptIDGT applies the GT predicate on the "script_id" field.
func ScriptIDGTE ¶
ScriptIDGTE applies the GTE predicate on the "script_id" field.
func ScriptIDHasPrefix ¶
ScriptIDHasPrefix applies the HasPrefix predicate on the "script_id" field.
func ScriptIDHasSuffix ¶
ScriptIDHasSuffix applies the HasSuffix predicate on the "script_id" field.
func ScriptIDIn ¶
ScriptIDIn applies the In predicate on the "script_id" field.
func ScriptIDIsNil ¶
ScriptIDIsNil applies the IsNil predicate on the "script_id" field.
func ScriptIDLT ¶
ScriptIDLT applies the LT predicate on the "script_id" field.
func ScriptIDLTE ¶
ScriptIDLTE applies the LTE predicate on the "script_id" field.
func ScriptIDNEQ ¶
ScriptIDNEQ applies the NEQ predicate on the "script_id" field.
func ScriptIDNotIn ¶
ScriptIDNotIn applies the NotIn predicate on the "script_id" field.
func ScriptIDNotNil ¶
ScriptIDNotNil applies the NotNil predicate on the "script_id" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func TypeValidator ¶
TypeValidator is a validator for the "type" field enum values. It is called by the builders before save.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Version ¶
Version applies equality check predicate on the "version" field. It's identical to VersionEQ.
func VersionContains ¶
VersionContains applies the Contains predicate on the "version" field.
func VersionContainsFold ¶
VersionContainsFold applies the ContainsFold predicate on the "version" field.
func VersionEqualFold ¶
VersionEqualFold applies the EqualFold predicate on the "version" field.
func VersionGTE ¶
VersionGTE applies the GTE predicate on the "version" field.
func VersionHasPrefix ¶
VersionHasPrefix applies the HasPrefix predicate on the "version" field.
func VersionHasSuffix ¶
VersionHasSuffix applies the HasSuffix predicate on the "version" field.
func VersionLTE ¶
VersionLTE applies the LTE predicate on the "version" field.
func VersionNEQ ¶
VersionNEQ applies the NEQ predicate on the "version" field.
func VersionNotIn ¶
VersionNotIn applies the NotIn predicate on the "version" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Indicator queries.
func ByCalculationCount ¶
func ByCalculationCount(opts ...sql.OrderTermOption) OrderOption
ByCalculationCount orders the results by the calculation_count field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByData ¶
func ByData(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByData orders the results by data terms.
func ByDataCount ¶
func ByDataCount(opts ...sql.OrderTermOption) OrderOption
ByDataCount orders the results by data count.
func ByEnabled ¶
func ByEnabled(opts ...sql.OrderTermOption) OrderOption
ByEnabled orders the results by the enabled field.
func ByErrorMessage ¶
func ByErrorMessage(opts ...sql.OrderTermOption) OrderOption
ByErrorMessage orders the results by the error_message field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIndicatorID ¶
func ByIndicatorID(opts ...sql.OrderTermOption) OrderOption
ByIndicatorID orders the results by the indicator_id field.
func ByLastCalculated ¶
func ByLastCalculated(opts ...sql.OrderTermOption) OrderOption
ByLastCalculated orders the results by the last_calculated field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByScriptID ¶
func ByScriptID(opts ...sql.OrderTermOption) OrderOption
ByScriptID orders the results by the script_id field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByStudySessionField ¶
func ByStudySessionField(field string, opts ...sql.OrderTermOption) OrderOption
ByStudySessionField orders the results by study_session field.
func ByType ¶
func ByType(opts ...sql.OrderTermOption) OrderOption
ByType orders the results by the type field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByVersion ¶
func ByVersion(opts ...sql.OrderTermOption) OrderOption
ByVersion orders the results by the version field.
type Status ¶
type Status string
Status defines the type for the "status" enum field.
type Type ¶
type Type string
Type defines the type for the "type" enum field.
const ( TypeRSI Type = "RSI" TypeMACD Type = "MACD" TypeBB Type = "BB" TypeMA Type = "MA" TypeEMA Type = "EMA" TypeSMA Type = "SMA" TypeWMA Type = "WMA" TypeSTOCH Type = "STOCH" TypeWILLIAMS_R Type = "WILLIAMS_R" TypeCCI Type = "CCI" TypeMOM Type = "MOM" TypeROC Type = "ROC" TypeADX Type = "ADX" TypeATR Type = "ATR" TypeVOLUME Type = "VOLUME" TypeOBV Type = "OBV" TypeVWAP Type = "VWAP" TypeICHIMOKU Type = "ICHIMOKU" TypeFIBONACCI Type = "FIBONACCI" TypePIVOT Type = "PIVOT" TypeCUSTOM Type = "CUSTOM" )
Type values.