Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.StudySession) predicate.StudySession
- func CreatedAt(v time.Time) predicate.StudySession
- func CreatedAtEQ(v time.Time) predicate.StudySession
- func CreatedAtGT(v time.Time) predicate.StudySession
- func CreatedAtGTE(v time.Time) predicate.StudySession
- func CreatedAtIn(vs ...time.Time) predicate.StudySession
- func CreatedAtLT(v time.Time) predicate.StudySession
- func CreatedAtLTE(v time.Time) predicate.StudySession
- func CreatedAtNEQ(v time.Time) predicate.StudySession
- func CreatedAtNotIn(vs ...time.Time) predicate.StudySession
- func ErrorCount(v int) predicate.StudySession
- func ErrorCountEQ(v int) predicate.StudySession
- func ErrorCountGT(v int) predicate.StudySession
- func ErrorCountGTE(v int) predicate.StudySession
- func ErrorCountIn(vs ...int) predicate.StudySession
- func ErrorCountLT(v int) predicate.StudySession
- func ErrorCountLTE(v int) predicate.StudySession
- func ErrorCountNEQ(v int) predicate.StudySession
- func ErrorCountNotIn(vs ...int) predicate.StudySession
- func ErrorMessage(v string) predicate.StudySession
- func ErrorMessageContains(v string) predicate.StudySession
- func ErrorMessageContainsFold(v string) predicate.StudySession
- func ErrorMessageEQ(v string) predicate.StudySession
- func ErrorMessageEqualFold(v string) predicate.StudySession
- func ErrorMessageGT(v string) predicate.StudySession
- func ErrorMessageGTE(v string) predicate.StudySession
- func ErrorMessageHasPrefix(v string) predicate.StudySession
- func ErrorMessageHasSuffix(v string) predicate.StudySession
- func ErrorMessageIn(vs ...string) predicate.StudySession
- func ErrorMessageIsNil() predicate.StudySession
- func ErrorMessageLT(v string) predicate.StudySession
- func ErrorMessageLTE(v string) predicate.StudySession
- func ErrorMessageNEQ(v string) predicate.StudySession
- func ErrorMessageNotIn(vs ...string) predicate.StudySession
- func ErrorMessageNotNil() predicate.StudySession
- func HasIndicatorData() predicate.StudySession
- func HasIndicatorDataWith(preds ...predicate.IndicatorData) predicate.StudySession
- func HasIndicators() predicate.StudySession
- func HasIndicatorsWith(preds ...predicate.Indicator) predicate.StudySession
- func HasSymbol() predicate.StudySession
- func HasSymbolWith(preds ...predicate.Symbol) predicate.StudySession
- func ID(id uuid.UUID) predicate.StudySession
- func IDEQ(id uuid.UUID) predicate.StudySession
- func IDGT(id uuid.UUID) predicate.StudySession
- func IDGTE(id uuid.UUID) predicate.StudySession
- func IDIn(ids ...uuid.UUID) predicate.StudySession
- func IDLT(id uuid.UUID) predicate.StudySession
- func IDLTE(id uuid.UUID) predicate.StudySession
- func IDNEQ(id uuid.UUID) predicate.StudySession
- func IDNotIn(ids ...uuid.UUID) predicate.StudySession
- func IntervalEQ(v Interval) predicate.StudySession
- func IntervalIn(vs ...Interval) predicate.StudySession
- func IntervalNEQ(v Interval) predicate.StudySession
- func IntervalNotIn(vs ...Interval) predicate.StudySession
- func IntervalValidator(i Interval) error
- func LastUpdate(v time.Time) predicate.StudySession
- func LastUpdateEQ(v time.Time) predicate.StudySession
- func LastUpdateGT(v time.Time) predicate.StudySession
- func LastUpdateGTE(v time.Time) predicate.StudySession
- func LastUpdateIn(vs ...time.Time) predicate.StudySession
- func LastUpdateIsNil() predicate.StudySession
- func LastUpdateLT(v time.Time) predicate.StudySession
- func LastUpdateLTE(v time.Time) predicate.StudySession
- func LastUpdateNEQ(v time.Time) predicate.StudySession
- func LastUpdateNotIn(vs ...time.Time) predicate.StudySession
- func LastUpdateNotNil() predicate.StudySession
- func MaxBars(v int) predicate.StudySession
- func MaxBarsEQ(v int) predicate.StudySession
- func MaxBarsGT(v int) predicate.StudySession
- func MaxBarsGTE(v int) predicate.StudySession
- func MaxBarsIn(vs ...int) predicate.StudySession
- func MaxBarsLT(v int) predicate.StudySession
- func MaxBarsLTE(v int) predicate.StudySession
- func MaxBarsNEQ(v int) predicate.StudySession
- func MaxBarsNotIn(vs ...int) predicate.StudySession
- func Name(v string) predicate.StudySession
- func NameContains(v string) predicate.StudySession
- func NameContainsFold(v string) predicate.StudySession
- func NameEQ(v string) predicate.StudySession
- func NameEqualFold(v string) predicate.StudySession
- func NameGT(v string) predicate.StudySession
- func NameGTE(v string) predicate.StudySession
- func NameHasPrefix(v string) predicate.StudySession
- func NameHasSuffix(v string) predicate.StudySession
- func NameIn(vs ...string) predicate.StudySession
- func NameIsNil() predicate.StudySession
- func NameLT(v string) predicate.StudySession
- func NameLTE(v string) predicate.StudySession
- func NameNEQ(v string) predicate.StudySession
- func NameNotIn(vs ...string) predicate.StudySession
- func NameNotNil() predicate.StudySession
- func Not(p predicate.StudySession) predicate.StudySession
- func Or(predicates ...predicate.StudySession) predicate.StudySession
- func SessionID(v string) predicate.StudySession
- func SessionIDContains(v string) predicate.StudySession
- func SessionIDContainsFold(v string) predicate.StudySession
- func SessionIDEQ(v string) predicate.StudySession
- func SessionIDEqualFold(v string) predicate.StudySession
- func SessionIDGT(v string) predicate.StudySession
- func SessionIDGTE(v string) predicate.StudySession
- func SessionIDHasPrefix(v string) predicate.StudySession
- func SessionIDHasSuffix(v string) predicate.StudySession
- func SessionIDIn(vs ...string) predicate.StudySession
- func SessionIDLT(v string) predicate.StudySession
- func SessionIDLTE(v string) predicate.StudySession
- func SessionIDNEQ(v string) predicate.StudySession
- func SessionIDNotIn(vs ...string) predicate.StudySession
- func SettingsIsNil() predicate.StudySession
- func SettingsNotNil() predicate.StudySession
- func StatusEQ(v Status) predicate.StudySession
- func StatusIn(vs ...Status) predicate.StudySession
- func StatusNEQ(v Status) predicate.StudySession
- func StatusNotIn(vs ...Status) predicate.StudySession
- func StatusValidator(s Status) error
- func UpdatedAt(v time.Time) predicate.StudySession
- func UpdatedAtEQ(v time.Time) predicate.StudySession
- func UpdatedAtGT(v time.Time) predicate.StudySession
- func UpdatedAtGTE(v time.Time) predicate.StudySession
- func UpdatedAtIn(vs ...time.Time) predicate.StudySession
- func UpdatedAtLT(v time.Time) predicate.StudySession
- func UpdatedAtLTE(v time.Time) predicate.StudySession
- func UpdatedAtNEQ(v time.Time) predicate.StudySession
- func UpdatedAtNotIn(vs ...time.Time) predicate.StudySession
- func ValidColumn(column string) bool
- type Interval
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByErrorCount(opts ...sql.OrderTermOption) OrderOption
- func ByErrorMessage(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIndicatorData(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByIndicatorDataCount(opts ...sql.OrderTermOption) OrderOption
- func ByIndicators(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByIndicatorsCount(opts ...sql.OrderTermOption) OrderOption
- func ByInterval(opts ...sql.OrderTermOption) OrderOption
- func ByLastUpdate(opts ...sql.OrderTermOption) OrderOption
- func ByMaxBars(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func BySessionID(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func BySymbolField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- type Status
Constants ¶
const ( // Label holds the string label denoting the studysession type in the database. Label = "study_session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldSessionID holds the string denoting the session_id field in the database. FieldSessionID = "session_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldInterval holds the string denoting the interval field in the database. FieldInterval = "interval" // FieldMaxBars holds the string denoting the max_bars field in the database. FieldMaxBars = "max_bars" // FieldSettings holds the string denoting the settings field in the database. FieldSettings = "settings" // FieldLastUpdate holds the string denoting the last_update field in the database. FieldLastUpdate = "last_update" // FieldErrorMessage holds the string denoting the error_message field in the database. FieldErrorMessage = "error_message" // FieldErrorCount holds the string denoting the error_count field in the database. FieldErrorCount = "error_count" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeSymbol holds the string denoting the symbol edge name in mutations. EdgeSymbol = "symbol" // EdgeIndicators holds the string denoting the indicators edge name in mutations. EdgeIndicators = "indicators" // EdgeIndicatorData holds the string denoting the indicator_data edge name in mutations. EdgeIndicatorData = "indicator_data" // Table holds the table name of the studysession in the database. Table = "study_sessions" // SymbolTable is the table that holds the symbol relation/edge. SymbolTable = "study_sessions" // SymbolInverseTable is the table name for the Symbol entity. // It exists in this package in order to avoid circular dependency with the "symbol" package. SymbolInverseTable = "symbols" // SymbolColumn is the table column denoting the symbol relation/edge. SymbolColumn = "symbol_study_sessions" // IndicatorsTable is the table that holds the indicators relation/edge. IndicatorsTable = "indicators" // IndicatorsInverseTable is the table name for the Indicator entity. // It exists in this package in order to avoid circular dependency with the "indicator" package. IndicatorsInverseTable = "indicators" // IndicatorsColumn is the table column denoting the indicators relation/edge. IndicatorsColumn = "study_session_indicators" // IndicatorDataTable is the table that holds the indicator_data relation/edge. IndicatorDataTable = "indicator_data" // IndicatorDataInverseTable is the table name for the IndicatorData entity. // It exists in this package in order to avoid circular dependency with the "indicatordata" package. IndicatorDataInverseTable = "indicator_data" // IndicatorDataColumn is the table column denoting the indicator_data relation/edge. IndicatorDataColumn = "study_session_indicator_data" )
const DefaultStatus = StatusActive
StatusActive is the default value of the Status enum.
Variables ¶
var ( // DefaultMaxBars holds the default value on creation for the "max_bars" field. DefaultMaxBars int // DefaultErrorCount holds the default value on creation for the "error_count" field. DefaultErrorCount int // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldSessionID, FieldName, FieldStatus, FieldInterval, FieldMaxBars, FieldSettings, FieldLastUpdate, FieldErrorMessage, FieldErrorCount, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for studysession fields.
var ForeignKeys = []string{
"symbol_study_sessions",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "study_sessions" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.StudySession) predicate.StudySession
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.StudySession
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.StudySession
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.StudySession
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.StudySession
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.StudySession
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.StudySession
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.StudySession
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.StudySession
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.StudySession
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func ErrorCount ¶
func ErrorCount(v int) predicate.StudySession
ErrorCount applies equality check predicate on the "error_count" field. It's identical to ErrorCountEQ.
func ErrorCountEQ ¶
func ErrorCountEQ(v int) predicate.StudySession
ErrorCountEQ applies the EQ predicate on the "error_count" field.
func ErrorCountGT ¶
func ErrorCountGT(v int) predicate.StudySession
ErrorCountGT applies the GT predicate on the "error_count" field.
func ErrorCountGTE ¶
func ErrorCountGTE(v int) predicate.StudySession
ErrorCountGTE applies the GTE predicate on the "error_count" field.
func ErrorCountIn ¶
func ErrorCountIn(vs ...int) predicate.StudySession
ErrorCountIn applies the In predicate on the "error_count" field.
func ErrorCountLT ¶
func ErrorCountLT(v int) predicate.StudySession
ErrorCountLT applies the LT predicate on the "error_count" field.
func ErrorCountLTE ¶
func ErrorCountLTE(v int) predicate.StudySession
ErrorCountLTE applies the LTE predicate on the "error_count" field.
func ErrorCountNEQ ¶
func ErrorCountNEQ(v int) predicate.StudySession
ErrorCountNEQ applies the NEQ predicate on the "error_count" field.
func ErrorCountNotIn ¶
func ErrorCountNotIn(vs ...int) predicate.StudySession
ErrorCountNotIn applies the NotIn predicate on the "error_count" field.
func ErrorMessage ¶
func ErrorMessage(v string) predicate.StudySession
ErrorMessage applies equality check predicate on the "error_message" field. It's identical to ErrorMessageEQ.
func ErrorMessageContains ¶
func ErrorMessageContains(v string) predicate.StudySession
ErrorMessageContains applies the Contains predicate on the "error_message" field.
func ErrorMessageContainsFold ¶
func ErrorMessageContainsFold(v string) predicate.StudySession
ErrorMessageContainsFold applies the ContainsFold predicate on the "error_message" field.
func ErrorMessageEQ ¶
func ErrorMessageEQ(v string) predicate.StudySession
ErrorMessageEQ applies the EQ predicate on the "error_message" field.
func ErrorMessageEqualFold ¶
func ErrorMessageEqualFold(v string) predicate.StudySession
ErrorMessageEqualFold applies the EqualFold predicate on the "error_message" field.
func ErrorMessageGT ¶
func ErrorMessageGT(v string) predicate.StudySession
ErrorMessageGT applies the GT predicate on the "error_message" field.
func ErrorMessageGTE ¶
func ErrorMessageGTE(v string) predicate.StudySession
ErrorMessageGTE applies the GTE predicate on the "error_message" field.
func ErrorMessageHasPrefix ¶
func ErrorMessageHasPrefix(v string) predicate.StudySession
ErrorMessageHasPrefix applies the HasPrefix predicate on the "error_message" field.
func ErrorMessageHasSuffix ¶
func ErrorMessageHasSuffix(v string) predicate.StudySession
ErrorMessageHasSuffix applies the HasSuffix predicate on the "error_message" field.
func ErrorMessageIn ¶
func ErrorMessageIn(vs ...string) predicate.StudySession
ErrorMessageIn applies the In predicate on the "error_message" field.
func ErrorMessageIsNil ¶
func ErrorMessageIsNil() predicate.StudySession
ErrorMessageIsNil applies the IsNil predicate on the "error_message" field.
func ErrorMessageLT ¶
func ErrorMessageLT(v string) predicate.StudySession
ErrorMessageLT applies the LT predicate on the "error_message" field.
func ErrorMessageLTE ¶
func ErrorMessageLTE(v string) predicate.StudySession
ErrorMessageLTE applies the LTE predicate on the "error_message" field.
func ErrorMessageNEQ ¶
func ErrorMessageNEQ(v string) predicate.StudySession
ErrorMessageNEQ applies the NEQ predicate on the "error_message" field.
func ErrorMessageNotIn ¶
func ErrorMessageNotIn(vs ...string) predicate.StudySession
ErrorMessageNotIn applies the NotIn predicate on the "error_message" field.
func ErrorMessageNotNil ¶
func ErrorMessageNotNil() predicate.StudySession
ErrorMessageNotNil applies the NotNil predicate on the "error_message" field.
func HasIndicatorData ¶
func HasIndicatorData() predicate.StudySession
HasIndicatorData applies the HasEdge predicate on the "indicator_data" edge.
func HasIndicatorDataWith ¶
func HasIndicatorDataWith(preds ...predicate.IndicatorData) predicate.StudySession
HasIndicatorDataWith applies the HasEdge predicate on the "indicator_data" edge with a given conditions (other predicates).
func HasIndicators ¶
func HasIndicators() predicate.StudySession
HasIndicators applies the HasEdge predicate on the "indicators" edge.
func HasIndicatorsWith ¶
func HasIndicatorsWith(preds ...predicate.Indicator) predicate.StudySession
HasIndicatorsWith applies the HasEdge predicate on the "indicators" edge with a given conditions (other predicates).
func HasSymbol ¶
func HasSymbol() predicate.StudySession
HasSymbol applies the HasEdge predicate on the "symbol" edge.
func HasSymbolWith ¶
func HasSymbolWith(preds ...predicate.Symbol) predicate.StudySession
HasSymbolWith applies the HasEdge predicate on the "symbol" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.StudySession
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.StudySession
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.StudySession
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.StudySession
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.StudySession
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.StudySession
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.StudySession
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.StudySession
IDNotIn applies the NotIn predicate on the ID field.
func IntervalEQ ¶
func IntervalEQ(v Interval) predicate.StudySession
IntervalEQ applies the EQ predicate on the "interval" field.
func IntervalIn ¶
func IntervalIn(vs ...Interval) predicate.StudySession
IntervalIn applies the In predicate on the "interval" field.
func IntervalNEQ ¶
func IntervalNEQ(v Interval) predicate.StudySession
IntervalNEQ applies the NEQ predicate on the "interval" field.
func IntervalNotIn ¶
func IntervalNotIn(vs ...Interval) predicate.StudySession
IntervalNotIn applies the NotIn predicate on the "interval" field.
func IntervalValidator ¶
IntervalValidator is a validator for the "interval" field enum values. It is called by the builders before save.
func LastUpdate ¶
func LastUpdate(v time.Time) predicate.StudySession
LastUpdate applies equality check predicate on the "last_update" field. It's identical to LastUpdateEQ.
func LastUpdateEQ ¶
func LastUpdateEQ(v time.Time) predicate.StudySession
LastUpdateEQ applies the EQ predicate on the "last_update" field.
func LastUpdateGT ¶
func LastUpdateGT(v time.Time) predicate.StudySession
LastUpdateGT applies the GT predicate on the "last_update" field.
func LastUpdateGTE ¶
func LastUpdateGTE(v time.Time) predicate.StudySession
LastUpdateGTE applies the GTE predicate on the "last_update" field.
func LastUpdateIn ¶
func LastUpdateIn(vs ...time.Time) predicate.StudySession
LastUpdateIn applies the In predicate on the "last_update" field.
func LastUpdateIsNil ¶
func LastUpdateIsNil() predicate.StudySession
LastUpdateIsNil applies the IsNil predicate on the "last_update" field.
func LastUpdateLT ¶
func LastUpdateLT(v time.Time) predicate.StudySession
LastUpdateLT applies the LT predicate on the "last_update" field.
func LastUpdateLTE ¶
func LastUpdateLTE(v time.Time) predicate.StudySession
LastUpdateLTE applies the LTE predicate on the "last_update" field.
func LastUpdateNEQ ¶
func LastUpdateNEQ(v time.Time) predicate.StudySession
LastUpdateNEQ applies the NEQ predicate on the "last_update" field.
func LastUpdateNotIn ¶
func LastUpdateNotIn(vs ...time.Time) predicate.StudySession
LastUpdateNotIn applies the NotIn predicate on the "last_update" field.
func LastUpdateNotNil ¶
func LastUpdateNotNil() predicate.StudySession
LastUpdateNotNil applies the NotNil predicate on the "last_update" field.
func MaxBars ¶
func MaxBars(v int) predicate.StudySession
MaxBars applies equality check predicate on the "max_bars" field. It's identical to MaxBarsEQ.
func MaxBarsEQ ¶
func MaxBarsEQ(v int) predicate.StudySession
MaxBarsEQ applies the EQ predicate on the "max_bars" field.
func MaxBarsGT ¶
func MaxBarsGT(v int) predicate.StudySession
MaxBarsGT applies the GT predicate on the "max_bars" field.
func MaxBarsGTE ¶
func MaxBarsGTE(v int) predicate.StudySession
MaxBarsGTE applies the GTE predicate on the "max_bars" field.
func MaxBarsIn ¶
func MaxBarsIn(vs ...int) predicate.StudySession
MaxBarsIn applies the In predicate on the "max_bars" field.
func MaxBarsLT ¶
func MaxBarsLT(v int) predicate.StudySession
MaxBarsLT applies the LT predicate on the "max_bars" field.
func MaxBarsLTE ¶
func MaxBarsLTE(v int) predicate.StudySession
MaxBarsLTE applies the LTE predicate on the "max_bars" field.
func MaxBarsNEQ ¶
func MaxBarsNEQ(v int) predicate.StudySession
MaxBarsNEQ applies the NEQ predicate on the "max_bars" field.
func MaxBarsNotIn ¶
func MaxBarsNotIn(vs ...int) predicate.StudySession
MaxBarsNotIn applies the NotIn predicate on the "max_bars" field.
func Name ¶
func Name(v string) predicate.StudySession
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.StudySession
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.StudySession
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.StudySession
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.StudySession
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.StudySession
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.StudySession
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.StudySession
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.StudySession
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.StudySession
NameIn applies the In predicate on the "name" field.
func NameIsNil ¶
func NameIsNil() predicate.StudySession
NameIsNil applies the IsNil predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.StudySession
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.StudySession
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.StudySession
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.StudySession
NameNotIn applies the NotIn predicate on the "name" field.
func NameNotNil ¶
func NameNotNil() predicate.StudySession
NameNotNil applies the NotNil predicate on the "name" field.
func Not ¶
func Not(p predicate.StudySession) predicate.StudySession
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.StudySession) predicate.StudySession
Or groups predicates with the OR operator between them.
func SessionID ¶
func SessionID(v string) predicate.StudySession
SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.
func SessionIDContains ¶
func SessionIDContains(v string) predicate.StudySession
SessionIDContains applies the Contains predicate on the "session_id" field.
func SessionIDContainsFold ¶
func SessionIDContainsFold(v string) predicate.StudySession
SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.
func SessionIDEQ ¶
func SessionIDEQ(v string) predicate.StudySession
SessionIDEQ applies the EQ predicate on the "session_id" field.
func SessionIDEqualFold ¶
func SessionIDEqualFold(v string) predicate.StudySession
SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.
func SessionIDGT ¶
func SessionIDGT(v string) predicate.StudySession
SessionIDGT applies the GT predicate on the "session_id" field.
func SessionIDGTE ¶
func SessionIDGTE(v string) predicate.StudySession
SessionIDGTE applies the GTE predicate on the "session_id" field.
func SessionIDHasPrefix ¶
func SessionIDHasPrefix(v string) predicate.StudySession
SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.
func SessionIDHasSuffix ¶
func SessionIDHasSuffix(v string) predicate.StudySession
SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.
func SessionIDIn ¶
func SessionIDIn(vs ...string) predicate.StudySession
SessionIDIn applies the In predicate on the "session_id" field.
func SessionIDLT ¶
func SessionIDLT(v string) predicate.StudySession
SessionIDLT applies the LT predicate on the "session_id" field.
func SessionIDLTE ¶
func SessionIDLTE(v string) predicate.StudySession
SessionIDLTE applies the LTE predicate on the "session_id" field.
func SessionIDNEQ ¶
func SessionIDNEQ(v string) predicate.StudySession
SessionIDNEQ applies the NEQ predicate on the "session_id" field.
func SessionIDNotIn ¶
func SessionIDNotIn(vs ...string) predicate.StudySession
SessionIDNotIn applies the NotIn predicate on the "session_id" field.
func SettingsIsNil ¶
func SettingsIsNil() predicate.StudySession
SettingsIsNil applies the IsNil predicate on the "settings" field.
func SettingsNotNil ¶
func SettingsNotNil() predicate.StudySession
SettingsNotNil applies the NotNil predicate on the "settings" field.
func StatusEQ ¶
func StatusEQ(v Status) predicate.StudySession
StatusEQ applies the EQ predicate on the "status" field.
func StatusIn ¶
func StatusIn(vs ...Status) predicate.StudySession
StatusIn applies the In predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v Status) predicate.StudySession
StatusNEQ applies the NEQ predicate on the "status" field.
func StatusNotIn ¶
func StatusNotIn(vs ...Status) predicate.StudySession
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.StudySession
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.StudySession
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.StudySession
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.StudySession
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.StudySession
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.StudySession
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.StudySession
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.StudySession
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.StudySession
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type Interval ¶
type Interval string
Interval defines the type for the "interval" enum field.
const ( Interval1s Interval = "1s" Interval5s Interval = "5s" Interval10s Interval = "10s" Interval15s Interval = "15s" Interval30s Interval = "30s" Interval1m Interval = "1m" Interval3m Interval = "3m" Interval5m Interval = "5m" Interval15m Interval = "15m" Interval30m Interval = "30m" Interval45m Interval = "45m" Interval1h Interval = "1h" Interval2h Interval = "2h" Interval3h Interval = "3h" Interval4h Interval = "4h" Interval6h Interval = "6h" Interval8h Interval = "8h" Interval12h Interval = "12h" Interval1d Interval = "1d" Interval3d Interval = "3d" Interval1w Interval = "1w" Interval1M Interval = "1M" )
Interval values.
type OrderOption ¶
OrderOption defines the ordering options for the StudySession queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByErrorCount ¶
func ByErrorCount(opts ...sql.OrderTermOption) OrderOption
ByErrorCount orders the results by the error_count field.
func ByErrorMessage ¶
func ByErrorMessage(opts ...sql.OrderTermOption) OrderOption
ByErrorMessage orders the results by the error_message field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIndicatorData ¶
func ByIndicatorData(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByIndicatorData orders the results by indicator_data terms.
func ByIndicatorDataCount ¶
func ByIndicatorDataCount(opts ...sql.OrderTermOption) OrderOption
ByIndicatorDataCount orders the results by indicator_data count.
func ByIndicators ¶
func ByIndicators(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByIndicators orders the results by indicators terms.
func ByIndicatorsCount ¶
func ByIndicatorsCount(opts ...sql.OrderTermOption) OrderOption
ByIndicatorsCount orders the results by indicators count.
func ByInterval ¶
func ByInterval(opts ...sql.OrderTermOption) OrderOption
ByInterval orders the results by the interval field.
func ByLastUpdate ¶
func ByLastUpdate(opts ...sql.OrderTermOption) OrderOption
ByLastUpdate orders the results by the last_update field.
func ByMaxBars ¶
func ByMaxBars(opts ...sql.OrderTermOption) OrderOption
ByMaxBars orders the results by the max_bars field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func BySessionID ¶
func BySessionID(opts ...sql.OrderTermOption) OrderOption
BySessionID orders the results by the session_id field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func BySymbolField ¶
func BySymbolField(field string, opts ...sql.OrderTermOption) OrderOption
BySymbolField orders the results by symbol field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.